import enUS from './en-US.json';
import plPL from './pl-PL.json';
import enGB from './en-GB.json';

export type Language = 'pl-PL' | 'en-GB' | 'en-US';
type ToStringable = { toString(): string };

interface Translations {
    [key: string]: ToStringable | Translations;
}

const ALL_TRANSLATIONS: Record<Language, Translations> = {
    'en-US': enUS,
    'pl-PL': plPL,
    'en-GB': enGB,
};

export default class LanguageManager {
    private translations: Translations = {};
    public language: Language;

    private readonly supportedLanguages: Language[] = ['pl-PL', 'en-GB', 'en-US'];
    private readonly fallbackLanguage: Language = 'en-US';

    public constructor(language: string) {
        this.language = this.isSupported(language) ? (language as Language) : this.fallbackLanguage;
        this.translations = ALL_TRANSLATIONS[this.language];
    }

    private isSupported(lang: string): lang is Language {
        return this.supportedLanguages.includes(lang as Language);
    }

    private getNestedValue(obj: any, path: string): unknown {
        return path
            .split('.')
            .reduce((acc, key) => (acc && key in acc ? acc[key] : undefined), obj);
    }

    public raw(key: string): unknown {
        return this.getNestedValue(this.translations, key);
    }

    public tr(key: string, map?: Record<string, ToStringable>): string {
        const raw = this.raw(key);
        let value = (raw as ToStringable)?.toString?.() ?? `N/A`;

        if (map) {
            for (const [placeholder, replacement] of Object.entries(map)) {
                value = value.replace(new RegExp(`{%${placeholder}%}`, 'g'), replacement.toString());
            }
        }

        return value;
    }
}