import styled from "styled-components";

import { useTheme } from "../style/themes";
import { useLanguage } from "../language/context";

import { calculateAge } from "../utils/math";
import { asCardStack } from "../components/card-stack";

const About: React.FC = () => {
    const age = calculateAge(new Date(2007, 6, 25));
    const { theme, toggleTheme } = useTheme();
    const { $, setLanguage } = useLanguage();

    return <>
        <Heading>{$.tr("hello")}.</Heading>
        <p>{$.tr("about", age)}</p>
        {asCardStack([
            {
                content: $.tr("switch_theme", {
                    theme: $.tr(
                        "theme." + (theme.type === "light" ? "dark" : "light")
                    )
                }),
                icon: "/icons/" + (theme.type === "light" ? "moon" : "sun") + ".svg",
                primary: theme.type === "light",
                onClick: toggleTheme
            },
            {
                content: $.tr("languages.pl"),
                icon: "/icons/countries/pl.svg",
                noeffects: true,
                onClick: () => setLanguage('pl-PL')
            },
            {
                content: $.tr("languages.en-US"),
                icon: "/icons/countries/us.svg",
                noeffects: true,
                onClick: () => setLanguage('en-US')
            },
            {
                content: $.tr("languages.en-GB"),
                icon: "/icons/countries/uk.svg",
                noeffects: true,
                onClick: () => setLanguage('en-GB')
            }
        ])}

        <h2>{$.tr("headers.facts")}</h2>
        {asCardStack($.raw("about_me") as string[])}

        <h2>{$.tr("headers.skills")}</h2>
        {asCardStack($.raw("skills") as string[])}

        <h2>{$.tr("headers.music")}</h2>
        {asCardStack([
            "black metal",
            "doom metal",
            "DSBM",
            "nu metal",
            "hard rock"
        ])}

        <h2>{$.tr("headers.bands")}</h2>
        <p><i>{$.tr("broad_music_spectrum")}</i></p>
        {asCardStack([
            "Mgła",
            "Behemoth",
            "Burzum",
            "Arkona",
            "Draconian",
            "Darkthrone",
            "Venom",
            "Slipknot",
            "None",
            "Lil Peep",
            "Alphaville",
            "MGMT",
            "ABBA",
            "Evanescence"
        ])}
    </>;
}

const Heading = styled.h1`
    font-family: "Pacifico", serif;
`;

export default About;